# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

from qtpy import QtCore

from prettyqt import core


QtCore.QMimeData.__bases__ = (core.Object,)


class MimeData(QtCore.QMimeData):

    def set_data(self, mime_type, data):
        self.setData(mime_type, QtCore.QByteArray(data.encode()))

    def get_data(self, mime_type):
        return bytes(self.data(mime_type)).decode()



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

from qtpy.QtCharts import QtCharts
from prettyqt import core


QtCharts.QAbstractSeries.__bases__ = (core.Object,)


class AbstractSeries(QtCharts.QAbstractSeries):

    """
    QAbstractSeries with some custom properties
    """

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self._group = ""

    @core.Property(object)
    def group(self):
        return self._group

    @group.setter
    def group(self, value):
        self._group = value
